@@ -1,14 +1,10 @@
 // Copyright (C) 2021 The Qt Company Ltd.
-// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0+ OR GPL-3.0 WITH Qt-GPL-exception-1.0
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #pragma once
 
-#include "dockerapi.h"
-
 #include <extensionsystem/iplugin.h>
 
-#include <optional>
-
 namespace Docker::Internal {
 
 class DockerPlugin final : public ExtensionSystem::IPlugin
@@ -19,12 +15,10 @@ class DockerPlugin final : public ExtensionSystem::IPlugin
 public:
     DockerPlugin();
 
-    static DockerApi *dockerApi();
-
 private:
     ~DockerPlugin() final;
 
-    bool initialize(const QStringList &arguments, QString *errorString) final;
+    void initialize() final;
 
     class DockerPluginPrivate *d = nullptr;
 };
